import requests
import boto3
import os
import uuid
import time

s3_client = boto3.client(
    "s3",
    aws_access_key_id=os.getenv('AWS_ACCESS_KEY'),
    aws_secret_access_key=os.getenv('AWS_SECRET_ACCESS_KEY'),
    region_name='us-east-1'
)

lambda_client = boto3.client(
    "lambda",
    aws_access_key_id=os.getenv('AWS_ACCESS_KEY'),
    aws_secret_access_key=os.getenv('AWS_SECRET_ACCESS_KEY'),
    region_name='us-east-1'
)

class Client():
    def __init__(self, name, token):
        self.name = name
        self.token = token
    
    def deploy(self, model_path, dependencies_path, proj_id, model_id):
        id = uuid.uuid4()

        response = requests.put("https://mb-cloudrun-backend-6816-7qerhjlmja-uc.a.run.app/api/model/update/", 
                        data={
                            "secretAccessToken": self.token,
                            "project_id": proj_id, 
                            "model_id": model_id,
                            "state": "PENDING"
                        }
        )

        if not response.status_code == 200:
            return

        with open(model_path, "rb") as f:
            s3_client.upload_fileobj(f, "mb-bucket-5125", "models/" + str(id) + ".joblib")
        with open(dependencies_path, "rb") as f:
            s3_client.upload_fileobj(f, "mb-bucket-5125", "dependencies/" + str(id))
        
        response = requests.post("https://mb-cloudrun-backend-6816-7qerhjlmja-uc.a.run.app/api/model/deploy/", data={"secretAccessToken": self.token, "id": id})

        while True:
            try:
                function_url = lambda_client.get_function_url_config(FunctionName=str(id))['FunctionUrl']
                break
            except:
                time.sleep(10)

        requests.put("https://mb-cloudrun-backend-6816-7qerhjlmja-uc.a.run.app/api/model/update/", 
                        data={
                            "secretAccessToken": self.token,
                            "project_id": proj_id, 
                            "model_id": model_id,
                            "state": "ACTIVE",
                            "model_url": function_url
                        }
        )




from setuptools import setup, find_packages
import codecs
import os


VERSION = '0.0.7'
DESCRIPTION = 'ModelBucket deployment package'
LONG_DESCRIPTION = 'A package that allows you to deploy models using ModelBucket.'

# Setting up
setup(
    name="model-bucket",
    version=VERSION,
    author="Adi_K527",
    author_email="<adikandakurtikar2@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['requests', 'boto3', 'uuid'],
    keywords=['python', 'ML', 'Deployment'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

